Index: content/public/browser/navigation_controller.h |
diff --git a/content/public/browser/navigation_controller.h b/content/public/browser/navigation_controller.h |
index 28d20d30b73a1ba48d4efeda07103c7f585fb631..e546ae5e2684b06c01d80ca7fc0e1e909969e67d 100644 |
--- a/content/public/browser/navigation_controller.h |
+++ b/content/public/browser/navigation_controller.h |
@@ -32,9 +32,10 @@ struct Referrer; |
class NavigationController { |
public: |
enum ReloadType { |
- NO_RELOAD, // Normal load. |
- RELOAD, // Normal (cache-validating) reload. |
- RELOAD_IGNORING_CACHE // Reload bypassing the cache, aka shift-reload. |
+ NO_RELOAD, // Normal load. |
+ RELOAD, // Normal (cache-validating) reload. |
+ RELOAD_IGNORING_CACHE, // Reload bypassing the cache (shift-reload). |
+ RELOAD_ORIGINAL_REQUEST_URL // Reload using the original request URL. |
}; |
// Creates a navigation entry and translates the virtual url to a real one. |